| Title: | Create Pharmacometric Models |
|---|---|
| Description: | Provides a user interface to create or modify pharmacometric models for various modeling and simulation software platforms. |
| Authors: | Sebastien Bihorel [cre, aut] |
| Maintainer: | Sebastien Bihorel <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.3.1 |
| Built: | 2026-06-07 08:31:11 UTC |
| Source: | https://github.com/sbihorel/pmxcode |
Run the Shiny Application
run_app( onStart = NULL, options = list(launch.browser = TRUE), enableBookmarking = NULL, uiPattern = "/", ... )run_app( onStart = NULL, options = list(launch.browser = TRUE), enableBookmarking = NULL, uiPattern = "/", ... )
onStart |
A function that will be called before the app is actually run.
This is only needed for |
options |
Named options that should be passed to the |
enableBookmarking |
Can be one of |
uiPattern |
A regular expression that will be applied to each |
... |
arguments to pass to golem_opts. See '?golem::get_golem_options' for more details. |
Starts the PMXcode Shiny application
## Not run: if( interactive() ){ pmxcode::run_app() } ## End(Not run)## Not run: if( interactive() ){ pmxcode::run_app() } ## End(Not run)